@@ -22,6 +22,7 @@ def get_rules():
         "ފި": "",
         "ގެ": "",
         "ތައް": "",
+        "ތަކަށް": "",
         "ކޮށް": "",
         "ނާ": "",
         "ވައި": "",
@@ -34,7 +35,6 @@ def get_rules():
         "ދުމާ": "ދުން",
         "ހުމެއް": "ހުން",
         "ކަމެއް": "ކަން",
-        "ތަކަށް": "ތް",
         "ސުން": "ސް",
         "ނުމުން": "ން",
         "ތުން": "ތް",
@@ -48,7 +48,7 @@ def stem(text):
     return value is a string. Otherwise a list is returned.
 
     ބަހުގެ ފަހަތުގައި ވާ އަކުރުތައް ނެގުމަށްފަހު ބަހުގެ އަސްލުގޮތް އަނބުރާ ދިނުން
-    
+
     >>> stem("އެކައްޗެއް")
     "އެކަތި"
     >>> stem(["ކަމެއްކަން", "ކަމެއްކަމަކީ", "ކަމެއްކަމުން", "ބަހެއް", "ގަހެއް", "އެކައްޗެއް"])
@@ -62,6 +62,8 @@ def stem(text):
     stems = []
     for i in tokens:
         stem = patterns.sub(lambda x: get_rules().get(x.group(), x.group()), i)
+        if stem == "":
+            continue
         stems.append(stem)
     if len(stems) == 1:
         stems = stems[0]
